@@ -68,9 +68,10 @@ class FLClient:
         self.logger.debug(f"[Client ID: {self.client_id: 03}] Received Tensor record (name,round)=(%s,%d)", name, round_number)
         if round_number > 1:
             self.time_get_tensor += end - start
-        shape = tuple(response.data_shape)
-        flat = np.frombuffer(response.data_bytes, dtype=np.float32)
+        shape = tuple(response.data_shape)                
+        flat = np.frombuffer(response.data_bytes, dtype=eval(response.data_dtype))        
         nparray = np.reshape(flat, newshape=shape, order="C")
+ 
         return nparray
 
     def get_weight(self, training_size):
