@@ -1,8 +1,9 @@
 from .federated_learning_pb2 import DataBuffer
 from .federated_learning_pb2 import TensorRecord
 
-def construct_tensor_record(name, nparray):
-    return TensorRecord(name=name, data_shape=list(nparray.shape), data_bytes=nparray.tobytes(order='C'))
+
+def construct_tensor_record(name, nparray):    
+    return TensorRecord(name=name, data_shape=list(nparray.shape), data_bytes=nparray.tobytes(order='C'), data_dtype="np."+str(nparray.dtype))
 
 def proto_to_databuffer(proto, max_message_size=(2*1024*1024)):
     data_bytes = proto.SerializeToString()
